/*
 *
 * Evolution calendar - Select source dialog
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with the program; if not, see <http://www.gnu.org/licenses/>
 *
 *
 * Authors:
 *		Rodrigo Moya <rodrigo@ximian.com>
 *
 * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
 *
 */

#ifndef SELECT_SOURCE_DIALOG_H
#define SELECT_SOURCE_DIALOG_H

#include <gtk/gtk.h>
#include <libedataserver/e-source.h>
#include <libecal/e-cal-client.h>

ESource *select_source_dialog (GtkWindow *parent, ECalClientSourceType type, ESource *except_source);

#endif
